//+------------------------------------------------------------------+
//|                                                  PPA_indi_v1.mq4 |
//|                                                         Zen Leow |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Zen Leow"
#property link      ""

#include <stdlib.mqh>
#include <stderror.mqh>
#property indicator_chart_window

#property indicator_buffers 2

// The color for displaying arrows
#property indicator_color1 Green       // Long signal
#property indicator_color2 Red         // Short signal

// Width of the arrows
#property indicator_width1 2  // Long signal arrow
#property indicator_width2 2  // Short signal arrow

extern bool OmitFirstCandle = true;
extern double Pip_Distance = 10;
extern color Text_Color = Blue;
extern int Text_Size = 15;


// Buffers for the calculations
double Up_Arrow_Buffer[];    // Long buffer for display
double Down_Arrow_Buffer[];   // Short buffer for display
int PipFactor = 1;
datetime TimeOfAttach = 0;
datetime TriggerTime = 0;
int todayOfYear = 0;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
// SetIndexStyle  - sets the new type, style, width and color for a given indicator line
   // SetIndexBuffer - binds the array variable declared at a global level to the custom indicator pre-defined buffer
   // SetIndexArrow  - sets an arrow symbol for indicators line of the DRAW_ARROW type.
   SetIndexStyle(0, DRAW_ARROW);
   SetIndexBuffer(0, Up_Arrow_Buffer);
   SetIndexArrow(0, 233); // Up arrow
   SetIndexStyle(1, DRAW_ARROW);
   SetIndexBuffer(1, Down_Arrow_Buffer);
   SetIndexArrow(1, 234); // Down arrow
//----
   WriteToLogFile("Start Of PPA Indicator");
   // Cater for fractional pips
   if (Digits == 3 || Digits == 5)
   {
      PipFactor = 10;
   }   
   TimeOfAttach = Time[0];
   return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
//----
   Comment("");
   ObjectDelete("candle_size");
//----
   return(0);
}

void WriteToLogFile(string input1)
{
   string filename = "PPA_Indi_"+Symbol()+"-"+Day()+"-"+Month()+"-"+Year()+".log";
   int handle = FileOpen(filename,FILE_READ|FILE_WRITE);
   if (handle>1)
   {
      string prefix1 = Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds()+" => ";
      FileSeek(handle, 0, SEEK_END); // go to end of file
      FileWrite(handle, prefix1 + input1);
      FileClose(handle);
   }
}

// This method is created to spawn a new file for a new day. The first line to be written sometimes don't get written.
// The dummy message used here can act as a buffer so that useful info don't get missed out.
void CreateNewLogFileIfNewDay()
{
   if (todayOfYear != DayOfYear())
   {
      todayOfYear = DayOfYear();
      WriteToLogFile("Dummy message");
   }
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   CreateNewLogFileIfNewDay();
   if (ObjectFind("candle_size")<0)
   {
      ObjectCreate("candle_size",OBJ_TEXT,0,Time[0],Low[0]);
   }
   ObjectSet("candle_size",OBJPROP_TIME1,Time[0]);
   ObjectSet("candle_size",OBJPROP_PRICE1,Low[0]);
   double csize = (High[0] - Low[0]) / Point / PipFactor;
   ObjectSetText("candle_size",DoubleToStr(csize,1),Text_Size,"Arial",Text_Color);
   
   if (OmitFirstCandle && TimeOfAttach == Time[0])
   {
      Comment("Skipping first candle");
      return(0);
   }
   if (TriggerTime > Time[0])
   {
      Comment("Arrow drawn. Waiting for new candle...");
      return(0);
   }
   else
   {
      Comment("Waiting for price to move "+DoubleToStr(Pip_Distance,0)+" pips.");
   }
   if (Close[0] - Open[0] >= (Pip_Distance * Point * PipFactor))
   {
      Up_Arrow_Buffer[0] = Close[0];
      Alert(Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds()+" => Buy Triggered");
      Print(Day(),"/",Month(),"/",Year()," - ",Hour(),":",Minute(),":",Seconds()," => Buy Triggered");
      WriteToLogFile ("BUY Signal Trigger at Price: "+DoubleToStr(Close[0],Digits));
      TriggerTime = TimeCurrent();
   }
   if (Open[0] - Close[0] >= (Pip_Distance * Point * PipFactor))
   {
      Down_Arrow_Buffer[0] = Close[0];
      Alert(Day()+"/"+Month()+"/"+Year()+" - "+Hour()+":"+Minute()+":"+Seconds()+" => Sell Triggered");
      Print(Day(),"/",Month(),"/",Year()," - ",Hour(),":",Minute(),":",Seconds()," => Sell Triggered");
      WriteToLogFile ("SELL Signal Trigger at Price: "+DoubleToStr(Close[0],Digits));
      TriggerTime = TimeCurrent();
   }
//----
   return(0);
}
//+------------------------------------------------------------------+